package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````K!\```````!``````````&`!`0``
M`````````$``.``)`$``%P`6``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0```!<`@``````
M`%P"````````7`(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````,2:````````Q)H`````````
M``$```````$````&````H/L```````"@^P$``````*#[`0``````X`0`````
M```X!0```````````0```````@````8```"P^P```````+#[`0``````L/L!
M``````#@`0```````.`!````````"``````````$````!````#@"````````
M.`(````````X`@```````"0`````````)``````````$`````````%#E=&0$
M````P),```````#`DP```````,"3````````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````*#[````````H/L!``````"@^P$`
M`````&`$````````8`0````````!``````````0````4`````P```$=.50`5
M47P,,=/,`+JG8TOOW[-5F5TQS"]L:6(O;&0M;75S;"UA87)C:#8T+G-O+C$`
M```1````2@````0````(````(1`0``7`!(`H`!`%@(9`A(*A``8)``2)B(`8
M0;H$`@A*````2P```$\```!4````50```%T```!>````7P````````!A````
M8@````````!C````9````&<```````````````&O-.C.WD<M;L7?'VI_FGSK
MT^\.+L6;MG94/)2XC?$.(/_D#M5DU'S9<5@<L@&+;YA/PYO"Y3\L0OK7A_JA
M;&!8[Y=YNN.2?.-'Q@%5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_J9R;OMI7
M&^"G`@IK&IY0H^#[20``````````````````````````````````````````
M`P`(`+@9`````````````````````````P`3`````@````````````````"/
M`@``$@````````````````````````"T`0``$@``````````````````````
M``!9````$@````````````````````````#5`@``$@``````````````````
M``````"Z````$0````````````````````````"(`0``$@``````````````
M```````````]````$@`````````````````````````R`0``$@``````````
M``````````````#W`0``$@````````````````````````"Q````$@``````
M``````````````````#,````(@````````````````````````!1`0``$@``
M``````````````````````#<`0``$@````````````````````````!]`@``
M$@````````````````````````"9`0``$@`````````````````````````5
M`0``$@````````````````````````"6`@``$@``````````````````````
M``#@`@``(0`````````````````````````W````$@``````````````````
M``````#?`@``$0````````````````````````#/`0``$0``````````````
M``````````!``0``$@````````````````````````!F`@``$@``````````
M``````````````!I````$@`````````````````````````6`@``$@``````
M``````````````````#A`@``$0````````````````````````"B````$@``
M```````````````````````]`@``$@`````````````````````````?````
M(`````````````````````````!F`0``$@````````````````````````#V
M````(`````````````````````````#>`@``(0``````````````````````
M``!Q````$@`````````````````````````0`0``$@``````````````````
M``````!A````$@````````````````````````!2````$@``````````````
M```````````0````$@`````````````````````````T`@``$@``````````
M``````````````"M`@``$@````````````````````````"H`0``$@``````
M``````````````````"`````(`````````````````````````"F`@``$@``
M``````````````````````!6`@``$@````````````````````````!+````
M$@`````````````````````````#`@``$@`````````````````````````!
M````$@````````````````````````!$````$@``````````````````````
M```N!```$@````````````````````````!(`@``$@``````````````````
M``````">`@``$@`````````````````````````)````$0``````````````
M```````````D`@``$@````````````````````````!R````$@``````````
M``````````````"$`@``$@`````````````````````````8````$@``````
M```````````````````;`0``$@````````````````````````#Q````$@``
M``````````````````````!U`0``%@````````````````````````"T`@``
M$@````````````````````````##`@``$@`````````````````````````Y
M`0``$@````````````````````````"<````$@``````````````````````
M``"J````$@````````````````````````!W````$@``````````````````
M``````!8`0``$@````````````````````````!Q`@``$@``````````````
M```````````L`0``$@````````````````````````#;````(```````````
M``````````````#M`0``$@````````````````````````"A````$@``````
M``````````````````#R`0``$@````````````````````````"/`P``$``4
M`-@``@````````````````"N`P``$@`*`(PT````````_`4```````"[`P``
M$@`*`,`\````````^`````````#0`@``$@`*`*`=````````#`(```````#)
M`0``$@`+`!12````````!``````````8`P``$@`*`/`G````````!```````
M```I`P``$``4`(```@`````````````````Z!```$@`(`+@9````````!```
M``````!;`P``$@`*```H````````7`(```````!P`P``$@`*`(@Z````````
M-`(```````#'`P``$``4`(```@````````````````!!`P``$@`*`!`Q````
M````>`````````!H`P``$@`*`(@Q````````C`````````"&`P``$@`*`(@F
M````````+`````````"C`P``$@`*`-!.````````@`$```````#3`P``$@`*
M`(@S````````!`$```````#[`P``$``4`-@``@`````````````````*!```
M$``4`-@``@`````````````````/!```$@`*`&`J````````+`````````":
M`P``$@`*`,@?````````*`````````!/`P``$@`*`(PJ````````=`$`````
M```W`P``$0`3`'@``@``````"``````````#!```$``3`(```@``````````
M``````#,`P``$@`*`*P?```````````````````W!```$@`*`)!.````````
M0``````````<!```$@`*`&@S````````(`````````".`P``$``4`-@``@``
M``````````````#E`P``$@`*`,`F````````,`$```````!`!```$@`*`%!0
M````````Q`$````````+`P``$@`*```L````````$`4`````````;W!E;F1I
M<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`7U]D97)E9VES=&5R7V9R86UE7VEN
M9F\`;'-E96L`9V5T<&ED`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`
M<W1R;F-M<`!S=')R8VAR`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E
M<E1-0VQO;F5486)L90!O<&5N`'9F<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?
M7W-T86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R
M86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`
M<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!M96UC<'D`<W1R;&5N`%]?
M<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES
M;6%L;&]C`'!E<FQ?86QL;V,`<W1R8W!Y`')E861D:7(`<W!R:6YT9@!S=')D
M=7``<W1R=&]K`'!T:')E861?871F;W)K`%]?;&EB8U]S=&%R=%]M86EN`'-N
M<')I;G1F`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM86%R8V@V
M-"YS;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T
M87)T7U\`;7E?<&%R7W!L`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`<&%R
M7V9I;F1P<F]G`'!A<E]D:64`6%-?26YT97)N86QS7U!!4E]"3T]4`'AS7VEN
M:70`7U]B<W-?96YD7U\`7W-T87)T7V,`<VAA7W5P9&%T90!P87)?;6MT;7!D
M:7(`<&%R7V-L96%N=7``7U]B<W-?<W1A<G0`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?96YD7U\`7V5D871A`%]E;F0`<&%R
M7V)A<V5N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'-H85]I;FET
M`'-H85]F:6YA;``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210"@^P$`
M``````,$````````S"````````"H^P$```````,$````````;"````````"@
M_P$```````,$````````N!D```````#0_P$```````,$````````H!T`````
M``#@_P$```````,$````````%%(```````````(```````,$```````````"
M```````8``(```````,$````````^%4````````@``(```````,$````````
MB%(````````P``(```````,$````````>%,````````X``(```````,$````
M````V%4```````!```(```````,$````````X%4```````!(``(```````,$
M````````Z%4```````!0``(```````,$````````\%4```````!@``(`````
M``,$````````P%4```````!H``(```````,$````````R%4```````!X``(`
M``````,$`````````%8```````"`_P$```````$$```'``````````````"(
M_P$```````$$```(``````````````"0_P$```````$$```-````````````
M``"8_P$```````$$```7``````````````"H_P$```````$$```<````````
M``````"P_P$```````$$```?``````````````"X_P$```````$$```A````
M``````````#`_P$```````$$```K``````````````#(_P$```````$$```M
M``````````````#8_P$```````$$```O``````````````#H_P$```````$$
M```U``````````````#P_P$```````8$```\``````````````#X_P$`````
M``$$``!&``````````````"H_0$```````($```#``````````````"P_0$`
M``````($```$``````````````"X_0$```````($```%``````````````#`
M_0$```````($```&``````````````#(_0$```````($```)````````````
M``#0_0$```````($```*``````````````#8_0$```````($```+````````
M``````#@_0$```````($```,``````````````#H_0$```````($```-````
M``````````#P_0$```````($```.``````````````#X_0$```````($```/
M````````````````_@$```````($```0```````````````(_@$```````($
M```1```````````````0_@$```````($```2```````````````8_@$`````
M``($```3```````````````@_@$```````($```5```````````````H_@$`
M``````($```8```````````````P_@$```````($```9```````````````X
M_@$```````($```:``````````````!`_@$```````($```;````````````
M``!(_@$```````($```=``````````````!0_@$```````($```>````````
M``````!8_@$```````($```?``````````````!@_@$```````($```@````
M``````````!H_@$```````($```C``````````````!P_@$```````($```D
M``````````````!X_@$```````($```E``````````````"`_@$```````($
M```F``````````````"(_@$```````($```G``````````````"0_@$`````
M``($```H``````````````"8_@$```````($```I``````````````"@_@$`
M``````($```J``````````````"H_@$```````($```L``````````````"P
M_@$```````($```N``````````````"X_@$```````($```P````````````
M``#`_@$```````($```Q``````````````#(_@$```````($```R````````
M``````#0_@$```````($```S``````````````#8_@$```````($```T````
M``````````#@_@$```````($```V``````````````#H_@$```````($```W
M``````````````#P_@$```````($```X``````````````#X_@$```````($
M```Y````````````````_P$```````($```Z```````````````(_P$`````
M``($```[```````````````0_P$```````($```]```````````````8_P$`
M``````($```^```````````````@_P$```````($```_```````````````H
M_P$```````($``!````````````````P_P$```````($``!!````````````
M```X_P$```````($``!"``````````````!`_P$```````($``!#````````
M``````!(_P$```````($``!$``````````````!0_P$```````($``!%````
M``````````!8_P$```````($``!&``````````````!@_P$```````($``!'
M``````````````!H_P$```````($``!(``````````````!P_P$```````($
M``!)``````````````#]>[^I_0,`D?U[P:C``U_6``````````#P>[^I\```
MT!'21OD0@C:1(`(?UA\@`]4?(`/5'R`#U?```-`1UD;Y$*(VD2`"'];P``#0
M$=I&^1#"-I$@`A_6\```T!'>1OD0XC:1(`(?UO```-`1XD;Y$`(WD2`"'];P
M``#0$>9&^1`B-Y$@`A_6\```T!'J1OD00C>1(`(?UO```-`1[D;Y$&(WD2`"
M'];P``#0$?)&^1""-Y$@`A_6\```T!'V1OD0HC>1(`(?UO```-`1^D;Y$,(W
MD2`"'];P``#0$?Y&^1#B-Y$@`A_6\```T!$"1_D0`CB1(`(?UO```-`1!D?Y
M$"(XD2`"'];P``#0$0I'^1!".)$@`A_6\```T!$.1_D08CB1(`(?UO```-`1
M$D?Y$((XD2`"'];P``#0$19'^1"B.)$@`A_6\```T!$:1_D0PCB1(`(?UO``
M`-`1'D?Y$.(XD2`"'];P``#0$2)'^1`".9$@`A_6\```T!$F1_D0(CF1(`(?
MUO```-`1*D?Y$$(YD2`"'];P``#0$2Y'^1!B.9$@`A_6\```T!$R1_D0@CF1
M(`(?UO```-`1-D?Y$*(YD2`"'];P``#0$3I'^1#".9$@`A_6\```T!$^1_D0
MXCF1(`(?UO```-`10D?Y$`(ZD2`"'];P``#0$49'^1`B.I$@`A_6\```T!%*
M1_D00CJ1(`(?UO```-`13D?Y$&(ZD2`"'];P``#0$5)'^1"".I$@`A_6\```
MT!%61_D0HCJ1(`(?UO```-`16D?Y$,(ZD2`"'];P``#0$5Y'^1#B.I$@`A_6
M\```T!%B1_D0`CN1(`(?UO```-`19D?Y$"([D2`"'];P``#0$6I'^1!".Y$@
M`A_6\```T!%N1_D08CN1(`(?UO```-`1<D?Y$(([D2`"'];P``#0$79'^1"B
M.Y$@`A_6\```T!%Z1_D0PCN1(`(?UO```-`1?D?Y$.([D2`"'];P``#0$8)'
M^1`"/)$@`A_6\```T!&&1_D0(CR1(`(?UO```-`1BD?Y$$(\D2`"'];P``#0
M$8Y'^1!B/)$@`A_6\```T!&21_D0@CR1(`(?UO```-`1ED?Y$*(\D2`"'];P
M``#0$9I'^1#"/)$@`A_6\```T!&>1_D0XCR1(`(?UO```-`1HD?Y$`(]D2`"
M'];P``#0$:9'^1`B/9$@`A_6\```T!&J1_D00CV1(`(?UO```-`1KD?Y$&(]
MD2`"'];P``#0$;)'^1""/9$@`A_6\```T!&V1_D0HCV1(`(?UO```-`1ND?Y
M$,(]D2`"']8`````````````````````_X,!T>,``-!CP$?Y_7L#J?W#`)'B
MAP"IXB,`D>%#`)'@'P"YX',`D?-3!*GU6P6I9`!`^>07`/D$`(#28?__E^(`
M`-!"[$?YX```T`#$1_GA`P*JL___E^```-``S$?Y``!`.4`)`#;@``#0`/A'
M^4'0.]7S``#P(FA@^/0?0+E!:%(Y@!(`$90.`!$A!``R06@2.0!\?9.^__^7
MXP,`JN8+0/GA``#P8N("D>`?0+DE/$#Y)```D,<`0/F$P!:19Q``J2$``)`A
MX!:10P0`^64$`:D?!`!Q#0D`5"$`@-(D#``1Q7AA^"$$`)%EV"3X'P`!:VS_
M_U0`#``1=>("D7_8(/@!``"PX@,4*B&`&)$$`(#2H`Y`^1+__Y<`!0`T=>("
MD?:3`)&@#D#Y7?__E_0#`"KA`Q:J(```D``@#)&(``"4(`0`M'/B`I%@#D#Y
MG/__EXO__Y?@``#0`,!'^>(70/D!`$#Y0@`!ZP$`@-+!!`!4_7M#J>`#%"KS
M4T2I]5M%J?^#`9'``U_65?__E_,``/!BX@*10`P`^2`#`+3<_O^7X```T`#X
M1_E!T#O5(FA@^%]8)3FP__\7H`Y`^1C__Y?7__\7H`I`^6```+14!P"4W?__
M%^$#%JH@``"0`$`*D5\``)2@"@#YX/K_M$P'`)35__\7@`"`4L#__Q<@`(!2
M0___E]+^_Y<=`(#2'@"`TN`#`)'A``#0(<`ND1_L?)(!```4X@,`J@4`@-+D
M``#0A/!'^4&$0/CC``#08]!'^>```-``Z$?Y.?__%Q\@`]4?(`/5'R`#U1\@
M`]7@``#0```"D>$``-`A``*1/P``Z\```%3A``"P(>!'^6$``+3P`P&J``(?
MUL`#7];@``#0```"D>$``-`A``*1(0``RR+\?]-!#(&+(?Q!D\$``+3B``"P
M0MQ'^6(``+3P`P*J``(?UL`#7];]>[ZI_0,`D?,+`/GS``#08`)".0`"`#?@
M``"P`,A'^8```+3@``#0``!`^7;^_Y?9__^7X```L`#81_F```"T(```\`#@
M$I&G_O^7(`"`4F`"`CGS"T#Y_7O"J,`#7];@``"P`/Q'^4`!`+3]>[^IX0``
MT"```/#]`P"1(2`"D0#@$I$8__^7_7O!J,[__Q?-__\7_7N\J>(``+!"U$?Y
M_0,`D?-3`:GW8P.I6`!`^?@%`+3U6P*I]P,`JO8#`:H``$`Y%0"`4A_T`'$$
M&$!ZH0(`5!,#0/FS`0"TM7Y`D_0#&*KB`Q6JX0,7JN`#$ZJ-_O^7@```-6!J
M=3@?]`!Q``(`5)..0/CS_O^U]5M"J>`#$ZKS4T&I]V-#J?U[Q*C``U_6]0,7
MJJ`>0#@?]`!Q!!A`>J'__U2U`A=+YO__%Y0"&,NU!@"1<P(5BY3^0Y/4`@"Y
MX`,3JO5;0JGS4T&I]V-#J?U[Q*C``U_6$P"`TNC__Q?_PP+1X@``L$+`1_GA
M(P"1_7L)J?U#`I'S4P#Y\P,`JD,`0/GC1P#Y`P"`TEG^_Y=``@`UX1M`N0(`
ME%(A#!02/Q!`<2000GK``0!4X0``L"'`1_GC1T#Y(@!`^6,``NL"`(#2H0$`
M5/-30/G]>TFI_\,"D<`#7]8``(!2]/__%^`#$ZI!`(!2BO[_EQ\``''@%Y\:
M[O__%Q[^_Y<?(`/5_P,#T>$``+`AP$?Y_7L)J?U#`I$B`$#YXD<`^0(`@-+`
M``"T\U,*J?,#`*H!`$`Y@0$`-?-32JG@``"P`,!'^>)'0/D!`$#Y0@`!ZP$`
M@-+!"`!4_7M)J?\#`Y'``U_6]5L+J4O^_Y?T`P"J8`8`M.`#%*KW_?^7@`4`
MM`%,0#D53`"1/[@`<<$``%2A!D`Y`?__-!\@`]4?(`/5'R`#U0!,0#D?N`!Q
MX`0`5.`#$ZIL_O^7]@,`JN`#%:II_O^7P`(`"P`(`!$`?$"3U?W_E^,#%:KB
M`Q.J]0,`J@$``/`AP`B1._[_E^$C`)'@`Q6J0/[_EQ\$`#&@``!4X!M`N0`,
M%!(?$$!QH`(`5.`#%:H$_O^7X`,5JGK^_Y?@`Q2JS/W_E\#Z_[7@`Q2J6?[_
ME^`#$ZK#_?^7\U-*J?5;2ZF^__\7H`9`.1^X`'$!^_]4H`I`.>#X_S35__\7
MX`,5JJC__Y?L__\7\U,*J?5;"ZG`_?^7'R`#U1\@`]4?(`/5_X,!T?U[`:G]
M0P"1\U,"J?,#`*KT`P&J]5L#J?=C!*G@``"P`,!'^2$`0#D"`$#YX@<`^0(`
M@-(_]`!QE!:4FN`#%*HG_O^7]@,`JN$3`)'@`Q.J*___ER`(`+3U`P"J(/[_
ME]\"`.OI!@!4]P>`N?@``+`8UT?Y]_)]TV`"0#D?]`!Q!!A`>L`+`%3D`Q.J
M@QQ`.'_T`'%D&$!ZH?__5(0`$\N$?$"3%0-`^<`*`)$```2+>_W_EZ!J-_B@
M`@"T`0-`^>`#$ZHC:'?X`11`.&$``#D_]`!Q)!A`>L```%0"%$`X8AP`.%_T
M`'%$&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S7@``"P`,!'
M^>('0/D!`$#Y0@`!ZP$`@-)!!P!4_7M!J?-30JGU6T.I]V-$J?^#`9'``U_6
M`0"`TH)J83BB:B$X(00`D:+__S7N__\7^```L!C71_GY:P6I%0"`4AH#0/E`
M`T#YH`0`M.`#&JH?(`/5`8Q`^.(#%2JU!@`1H?__M4`,`!$`?'V3X0``T"*X
M0+D"`@`U(@"`4B*X`+D]_?^7^0,`JB`#`+2W?GV3X0,:JN(#%ZH3_?^7&0,`
M^:`&`!'U!P"Y/]L@^/EK1:FH__\7X0,`JN`#&JIR_?^7``,`^?D#`*H@`0"T
MMWY]D_3__Q<$`(#2J?__%P`"@-+C__\7^6L%J3?]_Y?Y:T6IO?__%_U[OJDC
M``#P`0``\/T#`)%CP`V1\U,!J530.]7S``"P<_I'^>(``+!"Y$?Y(>`(D8!J
M<_@[_?^7@&IS^`0``/#S4T&IA*`6D?U[PJCC`P2J`@``L`$``/!"("J1(6`)
MD04`@%(#_?\7X```L`#X1_E$T#O5X@``L$+D1_DC``#P`0``\&/`#9&`:&#X
M(>`(D23]_Q<?(`/5'R`#U1\@`]7]>[ZI#02$TOT#`)'S4P&I_V,MR_\#`OG@
M``"P`,!'^?,C`)$!`$#YX0\0^0$`@-+0_/^7XP,`*@0``/`"``#PX`,3JH3`
M"9%"X`F1(0""TL3\_Y<?!``Q8`8`5`!\0),?!$#QZ`4`5``"@M+T8R"+X0,4
MJN`#$ZH"`(+2R?S_E_,#`*H`!?@W``0`$0!\0)/4_/^7XP,`JF`$`+1S?D"3
M'P`4ZX(``%0``!.+GP(`ZX,#`%1_`!3KZ`(`5"``@M)_`@#KZ`(`5.`#`ZKA
M`Q2JX@,3JJO\_Y?C`P"J'V@S..```+``P$?YX@]0^0$`0/E"``'K`0"`TJ$!
M`%0-!(32_V,MB^`#`ZKS4T&I_7O"J,`#7]:``A.+?P``ZP+]_U0`?2#4`P"`
MTN[__Q?!_/^7M/__%Q\@`]4?(`/5'R`#U?U[NZD-$H+2_0,`D?-3`:GU6P*I
M_V,MR_\#`OGU`P"JX@``L$+`1_GS`P&JX1,`D4``0/G@1PCY``"`T@```/``
M0`J1+_[_E_0#`*KA!8!2X`,5JBO]_Y=@`@"TX0,5J@```/``@`J1YO[_E^`#
M%:KA``"P(<!'^>-'2/DB`$#Y8P`"ZP(`@-(!#@!4#1*"TO]C+8OS4T&I]5M"
MJ?U[Q:C``U_6X`,3JM+\_Y<6``#PP<(*D<?\_Y?S`P"J`/W_M/=C"/GW(P*1
M^&<(^1@``/`8`PN1^6L(^1D``/`YXPJ1^F\(^6`"0#G@!``TM```M.$#$ZK@
M`Q2JROS_EP`#`#3@`Q.J]_S_EP($`-'Z`P"J8@("BW\"`NNC``!4"@``%%_T
M'SA_`@+K@```5$``0#D?O`!Q8/__5.`#$ZKI_/^7^@,`JN`#%:KF_/^7```:
MBP`(`)$?_#_QR0(`5,'""I$``(#2F_S_E_,#`*K`^_^U]V-(^?AG2/GY:TCY
M^F](^;?__Q>T!0"T@`)`.1^X`'&@``!4$P``\#H`@-)S(@J1Z?__%X`&0#F@
M_?\T^O__%^,#$ZKE`Q6JY`,9JN(#&*K@`Q>J`0""TA;\_Y<`!``1'P1`<4D`
M`%0`?2#4X2,`D>`#%ZJC_/^7H/O_->`;0+D`#!02'R!`<2'[_U3@`Q>J(0"`
M4J/\_Y>@^O\UX0,7J@```/``@`J1>O[_E^`#%ZIT_/^7]V-(^?AG2/GY:TCY
M^F](^8___Q<3``#P.@"`TG,B"I'`__\7]V,(^?AG"/GY:PCY^F\(^2;\_Y<?
M(`/5_7N^J>$%@%+]`P"1\PL`^?,#`*HG_/^7'P``\6`&@)KS"T#Y_7O"J%K\
M_Q?]>[ZI#0*"TOT#`)'_8RW+_P,"^>$``+`AP$?Y(@!`^>('"/D"`(#20`8`
MM/,3"/GT%PCY]`,`J@$`0#EA!0`TA?S_EP`$`)$?!$#Q"`<`5.$#%*KS(P"1
MX`,3JL+[_Y?@`Q.J?/S_EP`$`-%@`@"+'P`3ZZ@``%0'```4'_0?.!\`$^N`
M``!4`0!`.3^\`'%@__]4X`,3JN$%@%+Z^_^7H`0`M!\`$^OH`P!4X`,3JBW\
M_Y?A``"P(<!'^>,'2/DB`$#Y8P`"ZP(`@-+!!`!4\Q-(^0T"@M+T%TCY_V,M
MB_U[PJC``U_6\Q-(^?072/G@``"P`,!'^>('2/D!`$#Y0@`!ZP$`@-(!`P!4
M````\``@"I$-`H+2_V,MB_U[PJ@1_/\7'P``.>'__Q<``(#2X?__%^```+``
MP$?YX@=(^0$`0/E"``'K`0"`TL$``%3S$TCY````\/072/D`(`J1[?__%\#[
M_Y?S$PCY]!<(^;W[_Y?_@P'1X```L`#`1_G]>P&I_4,`D?-3`JD4``#P\Q,`
MD?5;`ZF4(@N1]V,$J?DK`/GU``"PM=9'^0$`0/GA!P#Y`0"`TN$#$ZK@`Q2J
M+?W_E^`!`+2B`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A
M__^UX0,3JN`#%*H?_?^78/[_M?4``+"UUD?Y%```\)1B"Y'A`Q.JX`,4JA?]
M_Y?@`0"TH@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__
MM>$#$ZK@`Q2J"?W_EV#^_[7U``"PM=9'^10``/"4@@N1X0,3JN`#%*H!_?^7
M``(`M*("0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A
M__^UX0,3JN`#%*KR_/^70/[_M?4``+"UUD?Y%```\)3""Y'A`Q.JX`,4JNK\
M_Y<@`@"TH@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`
M^0`@`)&A__^UX0,3JN`#%*K:_/^7(/[_M?8``+#6UD?Y%```\)7B"Y'A`Q.J
MX`,5JM+\_Y<@`@"TP@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!
M"$#Y`00`^0`@`)&A__^UX0,3JN`#%:K"_/^7(/[_M?8``+#6UD?Y%0``\+4B
M#)'A`Q.JX`,5JKK\_Y<@`@"TP@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#
MU1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:JJ_/^7(/[_M?<``+#WUD?Y
M%0``\+9""I'A`Q.JX`,6JJ+\_Y<@`@"TX@)`^>,'@+E`#`.+`01`^4%X(_CA
M_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%JJ2_/^7(/[_M?@`
M`+`8UT?Y%@``\-=B#)'A`Q.JX`,7JHK\_Y<@`@"T`@-`^>,'@+E`#`.+`01`
M^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#%ZIZ_/^7
M(/[_M?D``+`YUT?Y%P``\/BB#)'A`Q.JX`,8JG+\_Y<@`@"T(@-`^>,'@+E`
M#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M&*IB_/^7(/[_M?D``+`YUT?Y&```\!CC#)'A`Q.JX`,8JEK\_Y<@`@"T(@-`
M^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@`)&A__^U
MX0,3JN`#&*I*_/^7(/[_M?D``+`YUT?Y&```\!B#"I'A`Q.JX`,8JD+\_Y<@
M`@"T(@-`^>,'@+E`#`.+`01`^4%X(_CA_O^T'R`#U1\@`]4!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#&*HR_/^7(/[_M>$#$ZH```#0`"`-D2W\_Y?A`P"J8```
MM."B#)'I_/^7X0,3J@```-``@`V1)?S_E^$#`*J```"T````T`#@#9'@_/^7
MX0,3J@```-``(`Z1'/S_E^$#`*J``@"TH$(*D=C\_Y?@``"0`,!'^>('0/D!
M`$#Y0@`!ZP$`@-*!`@!4_7M!J8#B"Y'U6T.I`0``T/-30JDAP`Z1]V-$J?DK
M0/G_@P&1Q_S_%^$#$ZH```#0`&`.D0/\_Y?A`P"J0/W_M,!B#)&__/^7Y___
M%WGZ_Y?_@P#1````T.(``)!"P$?YX1,`D?U[`:G]0P"1`&`,D4,`0/GC!P#Y
M`P"`TO'[_Y?@`0"T``!`.1_``'$$&$!ZX`>?&N$``)`AP$?YXP=`^2(`0/EC
M``+K`@"`TL$``%3]>T&I_X,`D<`#7]8``(!2]?__%UOZ_Y?_@P31[`:`$ND`
M`)`IP4?Y[8,#D?U[!:G]0P&1ZP^`$NH``)!*]4?YX8L.J>$#`*KCDP^IX@,`
MD>6;$*GGCP#YX`<#K>(/!*WD%P6MYA\&K2,!0/GC)P#Y`P"`TN.#!)'CCP*I
M[1\`^>PO""E``4#Y_H/"//^#PSS^`X`]_P>`/=KZ_Y?@'X!2J/K_EQ\@`]4?
M(`/5'R`#U?U[O:G]`P"1\U,!J?5;`JG_0T#1_P,"^?]#`-'_`P+YXT-`D>$`
M`)`AP$?Y]0,`*D(`@%(D`$#Y9`0`^00`@-(!`(#2'_K_EQ8$`-'@`Q;KP3Y`
MD@`\0)(@1(#:U@(`ZR0&`%3S`P"1]```L.$#%JK@`Q4J`@"`4A+Z_Y<?!`"Q
MP`4`5`(!@-+A`Q.JX`,5*B(`H/(S^O^7'P0`,8`$`%0`?$"3'QP`\8D#`%0`
M(`#18`(`JZ,``%08```4``0`T1\`$^NC`@!4`0!`^8(&0/E?``'K0?__5```
M$\L``!:+X0``D"'`1_GC0T"19`1`^2(`0/F$``+K`@"`TD$"`%3_0P"1_T-`
MD?-30:GU6T*I_7O#J,`#7];60D#1WT)`L6'Z_U0``("2[O__%P```-``(`^1
MC?__EP```-``X`Z1BO__E^/Y_Y?]>[^I_0,`D<3Y_Y<O^O^70```M```0/G]
M>\&HP`-?UO\#`='A``"0(<!'^?U[`:G]0P"1\U,"J?0#`*KU6P.I%0``T+9B
M#Y$B`$#YX@<`^0(`@-+@`Q:JX1,`D4_[_Y>```"T\P,`J@``0#G@`0`UX```
MD`#`1_GB!T#Y`0!`^4(``>L!`(#2P00`5/U[0:GA`Q2JH&(/D?-30JGU6T.I
M_P,!D?W[_Q?@`Q2J,_K_E_4#`*K@`Q.J,/K_EZ`"`(L`"`"1G?G_E^0#$ZKB
M`Q2J\P,`J@,``-`!``#08\`*D2$`"Y$!^O^7X```D`#`1_GB!T#Y`0!`^4(`
M`>L!`(#2`0$`5/U[0:GA`Q.JX`,6JO-30JGU6T.I_P,!D=_[_Q>:^?^7_T,&
MT>(``+!"(`"1XP,!D42@`)']>Q.I_<,$D>$``)`AP$?Y\U,4J?.C`)%()$&I
M]5L5J?4#`*I&G$6I]V,6J?A#`)%>@,(\(`!`^>"7`/D``(#2G?Q`K>@G`:GT
M,P"111!`^>:?`JD6``#01#1`^7YT`*WA`Q2JP$(*D60*`/D%"P#Y?PB`/?OZ
M_Y>```"T`0!`.?<#`*H!%0`U^6L7J57Y_Y?`^?^70`X`M!D`0/D9#@"TX`,9
MJN?Y_Y<`^'_3``0`D53Y_Y?S`P"J(@-`.?<#`*HB`0`T&@``T%K##Y'@`Q.J
MX0,:JK?Y_Y=S"@"1(A]`.&+__S4```#0^2,!D0#@#9$#```4((=`^*`!`+3A
M`Q2JV/K_E_,#`*I@__^T`0!`.2'__S0+^_^7X/[_-.`#$ZJ,^?^7\P,`JF`!
M`+43`T#Y,P$`M&`"0#D@#``TX`,3J@#[_Y<`"P`U$P=`^1@C`)$S__^UX`,3
MJKKY_Y?X`P"JX`,7JK?Y_Y<9`P`+.1,0$1H``-`Y?T"3X`,9JB'Y_Y?E`Q>J
MX@,3JD/C"I$$``#0A.`/D?@#`*H!``#0(0`0D83Y_Y?@`QBJ`3B`4KWY_Y<?
M!``QH0``5)+Y_Y<$`$"YGT0`<>$)`%3APP&1X`,8JD#Y_Y?S`P`JH```->"#
M0+D`#!02'Q!`<6`'`%3@``"0`/1'^0$``-"B`D#YXP,8J@``0/DA0!&1(OG_
MEQ<`@-+@``"0`,!'^>*70/D!`$#Y0@`!ZP$`@-)A'0!4^6M7J>`#%ZK]>U.I
M\U-4J?5;5:GW8U:I_T,&D<`#7]9!^?^7<R(`D?D#`*I@`P"U8`)`^2`!`+3A
M`Q2J?OK_EV```+0!`$`YP?[_-6`&0/ES(@"1(/__M:`!@-+>^/^7&0``T/,#
M`*HYHP^1]P,`JF(*@%*)__\7X`,3JA@C`)$I^?^7\P,`JL#S_[2G__\7$P"`
MTJ7__Q=?^?^7`/A_TP`$`)%X__\7]XM`N<+X_Y?_`@!K8?C_5."#0+G[PP#Y
M`"``$A\`!W%@`P!4^\-`^;S__Q?@``"0`/1'^>,#&*JB`D#Y`0``T```0/DA
M0!"1W?C_E[O__Q?Q_O^7X```D`#`1_GBET#Y`0!`^4(``>L!`(#2X10`5/U[
M4ZG@`Q>J\U-4J?5;5:GW8U:I_T,&D?WX_Q?@`QFJI_C_E^$#%*KW`P"J````
MT`"@$I$Z^O^7X0,`JJ`*`+2@`D#Y]OO_E_L#`*H@"@"TX`,;JBKY_Y?Y`P"J
M'PP`<>T!`%0`?$"3`0``T``0`-$AP!*18`,`B_'X_Y<``0`U/Q,`<4`.`%0Y
M%P!18,MY.!^\`''`#0!4'R`#U>$#%*H4``#0@&(,D1WZ_Y>@``"T``!`.1_`
M`'$$&$!ZP0``5.`#&ZH!`(!2$?G_E_4#`"I`!@`U@&(,D0$``-`AP`Z1S_K_
MEUKC"I$5``#0M:(6D1D``-!6^/^7.<,3D>0#`"KC`QJJY0,5JN(#&*K@`Q>J
M`0``T"&`$Y'5^/^7#P``%.?X_Y<``$"Y'T0`<0$"`%1'^/^7<P8`$>0#`"KE
M`Q,JY@,5JN,#&JKB`QBJX0,9JN`#%ZK&^/^7X`,7J@$X@%+_^/^7'P0`,<#]
M_U3@`QBJ"_G_E^$#%ZK`0@J1J/K_E^`#%ZJ(_O^7^\-`^5#__Q>[`D#YK___
M%RG^_Y?Y`P"JH/G_MP$H`-$"`(!2X`,5*OO#`Y%2^/^7X`,5*N$#&ZK"`(#2
M=OC_EQ\8`/'!!0!4X?-`N0!@B%(@:*AR/P``:Z'W_U1A"T!Y`*F(4C\``&LA
M]_]4(<L`T0(`@%+@`Q4J\^,#D3[X_Y?@`Q4JX0,3J@(%@-)B^/^7'Z``\4$#
M`%3D`Q.J0^,*D>(#&*K@`Q>J!0``T`$``-"EH!:1(4`3D?^#!#F*^/^7R?__
M%[4&0/EU\O^TX`,5JJGX_Y<?#`#QZ?'_5``0`-$!``#0H`(`BR'@$I%R^/^7
M'P``<7L3E9J'__\7````T```$Y'&_?^7^\,`^1[X_Y?Y:Q>I^\,`^1OX_Y?_
M0P'1````T.(``)!"P$?Y`.`+D?U[`:G]0P"1\U,"J530.]7S``"0<_I'^?5;
M`ZGV$P"1X0,6JO<C`/F5:G/X0P!`^>,'`/D#`(#2HL)".:+&`CF)^?^7@```
MM`$`0#D_Q`!QP`H`5$3\_Y>5:G/XX`,5J@$``-!C`(!2(2`4D2(`@%)5^/^7
M]0,`JF`!`+2A"D#Y`@``T(!J<_A"0!21(0!`^?WW_Y>@"D#Y`0!`^2`,0+D`
M"K`W@&IS^`$``-!C`(!2(6`4D2(`@%+W``"P0OC_E_4#`*I@`0"TX0,6J@``
M`-``@`J19/G_E^(#`*K`!@"TH0I`^8!J<_@A`$#YYO?_EY5J<_@B`(!2`0``
MT"&`%)'@`Q6J$/C_EP(``-#A`P"J0N`4D>`#%:K;]_^7@FIS^//B`I'A`Q:J
M````T`!`"I%?Q`(Y3/G_EV`*`/F``@"T`3B`4ECX_Y<!!``1/P0`<02(47J!
M!0!4X```D`#`1_GB!T#Y`0!`^4(``>L!`(#2@00`5/<C0/G]>T&I\U-"J?5;
M0ZG_0P&1P`-?UF`&0/D8_O^78`H`^4#]_[4```#0```5D7#W_Y<`!$`Y@/7_
M-*G__Q><^O^7H0I`^?4#`*J`:G/X(0!`^34!`+3B`Q6JK??_E^`#%:I#^/^7
MQ?__%X!J<_AT]_^7K___%^+B`I%"!$#Y0@!`^:/W_Y>]__\7E??_E_?B`I'C
M`P`J````T`"@%9'ABD"I(0!`^5+W_Y<?(`/5_\,`T>$``)`AP$?Y_7L!J?U#
M`)'S4P*I\P,`J@```-`B`$#YX@<`^0(`@-(`8`R1X1,`D0/Y_Y<@`0"T``!`
M.1_``'$$&$!ZX`>?&G\"`/'A!Y\:/P``:H$!`%3@``"0`,!'^>('0/D!`$#Y
M0@`!ZP$`@-(!!`!4_7M!J?-30JG_PP"1P`-?UF`"0#F`_O\TX`,3JD[[_Y?A
M!8!2]`,`JFSW_Y<?``#Q@`:`FJ'W_Y<!``#0@@"`TB'@#Y&%]_^7X/S_->``
M`)``P$?YX@=`^0$`0/E"``'K`0"`TL$``%3]>T&IX`,3JO-30JG_PP"1-/G_
M%T_W_Y<?(`/5'R`#U?U[OZD!X`"1!.`!D>,``)!CP$?Y_0,`D14$`$__0PK1
MEN0`;V4`0/GE1P'Y!0"`TO?E`&_B`P"16N0`;^,#`)$[?$!M/03!/'L[GPZ_
M!V!OO@=8;[P'2&]["R`N_5=(3_]76$_>'SI.>#N53KT?-D[_'S=.WA^\3K\?
MOT[Y'[Y.>(R?3#\`!.O!_?]4^1_`/4*@"9'XY0!OX:,!D?_[0*W]\T&M^^M"
MK2%``)$@@-@\(0#?//4?/&[?'[Y.(!P@;KX?O4Z='[Q.?!^[3A4<-6Y;'[I.
M.A^Y3K8&86^U5D%/U1ZU3KD>.$XY@(`\7P`!Z\']_U0&)$"I)3./T@<@0:E%
M4*ORX3=`J21TG=(*$$#YPOQ;TP,!!\I"%`:J8P`)BBO]0M-C``C*(0`%BR$`
M"HMB0"*+0@`!"VMY":IN?4"2K0$%BT'\6]/,`0?*(10"JHP!!HHA``V+C`$'
MRNU#0:G#_$+3C`$(BV-X!JHA``P+:P$#RFL!`HI/_$+3+/Q;TVL!#LJM`06+
MC!4!JHP!#8MK`0>+BP$+"^)Y`JIO?$"28P`"RF,``8IM_5O3#`(%BV,`#\JM
M%0NJ8P`.BZT!#(LL_$+3[A-`^:T!`PN!>0&J)-NM\JS]6]-#``'*S@$%BXP5
M#:I"?$"2C`$.BV,`"XKNPT*I8P`"RF,`#XMO_4+3@P$#"^MY"ZHO?$"2(0`+
MRFS\6],A``V*S@$%BXP5`ZHA``_*C`$.BR$``HNB_4+3@0$!"T)X#:IL`0+*
M;GU`DHP!`XHM_%O3"P(%BXP!#LJM%0&JC`$/BZT!"XMO_$+3\!]`^:L!#`OC
M>0.J3WQ`DD(``\IL_5O30@`!B@T"!8N,%0NJ0@`/RHP!#8M"``Z++?Q"TX(!
M`@OP(T#YH7D!JFP``<IN?$"2C`$+BDW\6],#`@6+C`$.RJT5`JJ,`0^+K0$#
MBV_]0M/P)T#YHP$,"^MY"ZHO?$"2;/Q;TR$`"\H-`@6+(0`"BHP5`ZHA``_*
MC`$-BTW\0M.B>0*J(0`.BX$!`0ML`0+*;GU`DHP!`XJ,`0[*+?Q;TXP!#XNM
M%0&J\#]%J0L"!8MP_$+3`WH#JJT!"XM0?$"20@`#RJL!#`M"``&*0@`0RNT!
M!8ML_5O30@`.B^Y'1JF,%0NJC`$-BRW\0M."`0(+H7D!JFP``<IO?$"2C`$+
MBDW\6]/#`06+C`$/RJT5`JJ,`1"+K0$#BV/]0M.N`0P+:W@+JB,`"\HP?$"2
M8P`"BL']6],L`@6+(10.JF,`$,HA``R+8P`/BTS\0M,A``,+@GD"JN-'1ZEL
M`0+*;WU`DHP!#HHM_%O3C`$/RJT5`:J,`1"+4'Q`DF,`!8NM`0.+P_U"TZT!
M#`MC>`ZJ0@`#RBP"!8NK_5O30@`!BFL5#:I"`!#*:P$,BT(`#XMO`0(++/Q"
MT^)'2*F!>0&J:P`!RFY\0))K`0V*[/U;TVL!#LJ,%0^J:P$0BS!\0))"``6+
MC`$"BZ+]0M.,`0L+0G@-JB$``LHK`@6+@_U;TR$`#XIC%`RJ(0`0RB$`#HMC
M``N+;0`!"^']0M/N2T#Y(7@/JDL``<JC_5O30GQ`DFL!#(IC%`VJ:P$"RLX!
M!8MR`1"+PT$CBXO]0M-Q`!(+;'D,JNY/0/DK``S*+_Y;TR%\0)+O%1&J:P$-
MBFL!`<K%`06+?@$"BZ)`+XM/`!X+I?U"T^Y30/FM>`VJ\/U;TV,`$HL0%@^J
MD@$-RE("`TK#`02+4@(!BV%`,(LP`!(+(_Y"T^M70/EE>!&J#OY;TZ,!!<K.
M%1"J0@`>BVL!!(MB``)*3$`LBV)!+HM1``P+X_U"T^M;0/EC>`^J+OY;TZ\`
M`\K.%1&J(0`2B^$!`4IK`02++4`MBV%!+HLK``T+#_Y"T^Y?0/GP>1"J;_U;
MTT(`#(OO%0NJ;``0RH(!`DK.`02+14`EB\)!+XM>``4++/Y"T^YC0/F,>1&J
MS_];TR$`#8OO%1ZJ#0(,RJ$!`4K-`02+(T`CBZ%!+XLQ``,+;?U"T^YG0/FK
M>0NJ+_Y;TT(`!8OO%1&JA0$+RJ(``DK.`02+34`PB\)!+XM2``T+Q?]"T^YK
M0/FE>!ZJ3_Y;TR$``XOO%1*J8P$%RF$``4K.`02++$`LB\%!+XLP``P+(_Y"
MT^YO0/EC>!&J#_Y;TT(`#8OO%1"JK0`#RJ(!`DK.`02+2T`KB\)!+XM1``L+
M3?Y"T^YS0/FM>1*J+_Y;TR$`#(OO%1&J;``-RH$!`4K.`02+)4`EB\%!+XLR
M``4+#/Y"T^YW0/F,>1"J3_Y;TT(`"XOO%1*JJP$,RF(!`DK.`02+0T`CB\)!
M+XM0``,+*_Y"T^Y[0/EK>1&J#_Y;TR$`!8OO%1"JA0$+RJ$``4K.`02++4`M
MB\%!+XLQ``T+1?Y"T^Y_0/FE>!*J+_Y;TT(``XOO%1&J8P$%RF(``DK.`02+
M3$`LB\)!+XM.``P+`_Y"T^^#0/EC>!"JT/U;TR$`#8L0%@ZJK0`#RJ$!`4KM
M`02+*T`KBZ%!,(LP``L++_Y"T^V'0/GQ>1&J#_Y;TT(`#(OO%1"J;``1RH(!
M`DJL`02+14`EBX)!+XM,``4+S_U"T^V+0/GN>0ZJC_U;TR$`"XOO%0RJ*P(.
MRF$!`4JK`02+(T`CBV%!+XLK``,+#_Y"T^V/0/GP>1"JT@$0RF_]6]-"``6+
MY14+JD("`DJM`02+3T`QBX+]0M-,>`RJI4$EB[$`#PLA``.+`P(,RJ4`#XOM
MDT#Y8P`!2F']0M,B_EO3*W@+JD(4$:J/`0O*K0$$B^\!!4JB02*+_D$PBW)`
M+HOMOU*I3@`2"R/^0M/!_5O38W@1JB$4#JJE`02+30`2BZ%`(8MB`0/*,``>
M"T(`#4KM`02+0D`LBP7^6],A`!Z+I100JJ4`#8NL``(+POU"T^V?0/E">`ZJ
M;@`"RH7]6]/!`0%*K0$$BR%`*XND%`RJ"_Y"TX0`#8MP>1"JCP`!"^6C0/E+
M`!"J`0(""FL!#(IK`0&JY/U;TX&;E]*$%`^J8>.Q\J4``8MC02.+A``%BX7]
M0M.-``,+Y*=`^:QX#*H+`@RJA0$0"FL!#XJC_5O3:P$%JH0``8MC%`VJ8D$B
MBV,`!(OE_4+3Y*M`^:]X#ZIN``(+@@$/JN,!#`I"``V*R_U;TT(``ZIK%0ZJ
M@P`!BT5`,(MK`0.+L?U"TV(!!0OCKT#Y+7H-JNL!#:JD`0\*:P$.BD7\6]-C
M``&+:P$$JJ44`JID02R+I0`#B\O]0M/CLT#Y;GD.JJP`!`ND`0ZJQ0$-"H0`
M`HJ+_5O3A``%JFL5#*IE``&+4/Q"TX-`+XMK`06+!'H"JN6W0/EP`0,+RP$$
MJH(`#@IK`0R*`_Y;TZ4``8MK`0*J8Q00JF)!+8MC``6+B_U"T^6[0/EL>0RJ
M;P`""X(`#*J#`00*0@`0BNO]6]-"``.J:Q4/JJ,``8L-_D+314`NBVL!`XNB
M>1"JX[]`^6T!!0N+`0*J3@`,"FL!#XJE_5O3:P$.JF,``8NE%`VJ9$$DBZ4`
M`XOK_4+3X\-`^6]Y#ZJN``0+1``/JN4!`@J$``V*R_U;TX0`!:IK%0ZJ90`!
MBVL!!8N#0"R+L/U"TVP!`PODQT#Y#7H-JNL!#:JE`0\*:P$.BH/]6]-K`06J
MA``!BV,4#*K%_4+3KG@.JF)!(HMC``2+Q0$-"F,``@NB`0ZJ0@`,BI#]0M-"
M``6J:_Q;TT5`+XMK%0.JY#]9J0QZ#*J$``&+[P$!BVL!!(N$`0X*8@$%"\L!
M#*IK`0.*1?Q;TVL!!*JE%`*J9$$MBZ4`#XMK_$+3[=-`^:\`!`ME>0.J4/Q"
MTX0!!:JC``P*A``"BNO]6].M`0&+A``#JFL5#ZJ#0"Z+:P$-BP1Z`JIN`0,+
MJP`$JH(`!0IK`0^*:P$"JL/]6]-B02R+8Q0.JNVS6JGK_4+3K0$!BXP!`8MC
M``V+;0`""V-Y#ZJ"``.J<``$"D(`#HJK_5O3S_U"TT(`$*IK%0VJ14`EBVL!
M#(OB>0ZJ;P$%"VL``JI.``,*:P$-BFL!#JKE_5O39$$DBZ44#ZKLKUNIC`$!
MBVL!`8NE``R+K/U"TZX`!`N->0VJ10`-JK`!`@JE``^*Q/U;TZ4`$*KL_4+3
MA!0.JH]Y#ZJC0".+A``+B^7G0/F,``,+I`$/JNL!#0J$``Z*@_U;TX0`"ZJE
M``&+@D`BBV,4#*K$_4+38P`%BX5X#JIK``(+XP$%JJX`#PIC``R*8OU;TV,`
M#JI"%`NJ<D`MBX/]0M/D-UVI;'@,JHX!!0J$``&+H0$!BX)`(HND``RJ4``2
M"X0`"XJ$``ZJ`_Y;TY%`+XMC%!"J(T`CBV']0M-D`!$+*W@+JH\!"\I!`!*+
MCOQ;TV,`$8O"%02J[@$!2L5!)8O!.IC2[3M>J4%,N?(/_D+3\'D0JG$!$,HC
M`@-*K0$!B\X!`8NB02*+;$`LBTT`!0M"``6+K_U;T^\5#:K#02^+C_Q"TWX`
M#`OD>02J[OM`^<__6],%`@3*[Q4>JJ(``DK%`0&+2T`KBZ)`+XM2``L+I?U"
MT^[_0/FM>`VJ3_Y;TX4`#<KO%1*J8P`,B\X!`8NC``-*94`PB\-!+XMQ``4+
MS/]"T^X#0?F,>1ZJ+_Y;TT(`"XOO%1&JJP$,RF(!`DK.`0&+1$`DB\)!+XM0
M``0+2_Y"T^X'0?EK>1*J#_Y;TV,`!8OO%1"JA0$+RJ,``TK.`0&+;4`MB\-!
M+XMR``T+)?Y"T^X+0?FE>!&J3_Y;TT(`!(OO%1*J9`$%RH(``DK.`0&+3$`L
MB\)!+XM1``P+!/Y"T^X/0?F$>!"J+_Y;TV,`#8OO%1&JK0`$RJ,!`TK.`0&+
M:T`KB\-!+XMP``L+3?Y"T^X30?FM>1*J#_Y;TT(`#(OO%1"JC``-RH(!`DK.
M`0&+14`EB\)!+XM2``4++/Y"T^X70?F,>1&J3_Y;TV,`"XOO%1*JJP$,RF,!
M`TK.`0&+9$`DB\-!+XMQ``0+"_Y"T^X;0?EK>1"J+_Y;TT(`!8OO%1&JA0$+
MRJ(``DK.`0&+34`MB\)!+XM0``T+1?Y"T^X?0?FE>!*J#_Y;TV,`!(OO%1"J
M9`$%RH,``TK.`0&+;$`LB\-!+XMR``P+)/Y"T^XC0?F$>!&J3_Y;TT(`#8OO
M%1*JK0`$RJ(!`DK-`0&+2T`KBZ)!+XM1``L+#?Y"T^XG0?FP>1"J+_Y;TV,`
M#(OO%1&JC``0RH,!`TK,`0&+94`EBX-!+XM^``4+3?Y"T^PK0?FM>1*JSO];
MTT(`"XO.%1ZJ"P(-RF(!`DJ+`0&+1$`DBV)!+HM,``0+*_Y"T^\O0?EQ>1&J
MCOU;TV,`!8O.%0RJI0$1RJ4``TKC`0&+LD`PBVY`+HO%`1(+R_]"T^,S0?EK
M>1ZJK_Q;TS`""\I"``2+Y!4%J@("`DIC``&+7D`MBV)`)(M#`!X+A/U"T^\W
M0?F,>`RJ9/Q;TW`!#,K.`1*+A!0#JA`"#DKN`0&+$4(QB\1!)(OO.T'YC@`1
M"ZW\0M.$`!&+K7D%JD4`'HN0`0W*POU;TQ`"!4I"%`ZJY0$!BPM"*XM"``6+
M9?Q"T^\_0?E"``L+HW@#JLQ`+(NE`0/*2_Q;TV85`JJD``1*X0$!B\7]0M.$
M``&+Q@`,BZ%X#JJE`0H+R@``\$K!1_E"``D+(0`'"V,`"`N$``8+!`@`J0$,
M`:D%$`#YXD=!^4$!0/E"``'K`0"`TH$``%3_0PJ1_7O!J,`#7]89\_^7_7N_
MJ0`0@-+]`P"1`?/_ER(``+`A``"P'Q@`^5WHP#TB``"P/N3`/1]X`+E?[,`]
M'G0`K1\(@#W]>\&HP`-?UOU[NZE"?$"3_0,`D?-3`:GT`P*J]5L"J17@`)'W
M8P.I]P,!JODC`/GY`P"J!8Q"J0%X0+FD#`(+OP`$ZV.4@YIB=$*+!(@"J2$#
M`#03"(!2<P(!2W\"%&L5X`"1<]*4&J#"(8MB?D"3'P`7ZP,(`%3V`@*+:0``
M5!\`%NO#!`!4X0,7JKOR_Y<A>T"Y80(!"R%[`+D_``%Q804`5)0"$TOW`Q:J
MX`,9JI+[_Y>?_@!Q30,`5/,#%ZHXXP&1]@(!D0\``!1_`ACK8P(`5/<#%JI]
M<D"MX`,9JG]Z0:V4`@%1O7(`K7,"`9'6`@&1OWH!K8#[_Y>?_@!Q#0$`5+\"
M$^LC_O]4]P,6JDG^_U2_`A;K`O[_5`!](-2"?D"3OP(7Z^,!`%2)``!4X`("
MB[\"`.LC__]4X0,7JN`#%:J-\O^7-'L`N?DC0/GS4T&I]5M"J?=C0ZG]>\6H
MP`-?UJ`"`HO_`@#K@O[_5`!](-0!``*+]@("B_\"`>M"^/]4`'T@U/U[O*GC
M#X`2_0,`D?-3`:GT`P"J\P,!JO5;`JDVX`"1[QL`_36`0JFB(@-3#P!GGD$$
M`!$@?$"3P\HB.,`"`(L_X`!Q30L`5`((@%)"``%+`0"`4D)\0)/6\O^7X`,3
MJD3[_Y<?!`!/?X*#/-_^`*U_-@#Y^@5P?_\%:'_[!7A_O@)GGN`#$ZK<!VA_
MW0=P?U\'`V[>!WA_?P<%;O\%!VZ?!PENOP<+;M\'#6Z_'@].?SH`_2_[_Y=A
M`D#YX`,3JB'\6-.!`@`Y80)`^2'\4-.!!@`Y80)`^2'\2-.!"@`Y80)`^8$.
M`#EA!D#Y(?Q8TX$2`#EA!D#Y(?Q0TX$6`#EA!D#Y(?Q(TX$:`#EA!D#Y@1X`
M.6$*0/DA_%C3@2(`.6$*0/DA_%#3@28`.6$*0/DA_$C3@2H`.6$*0/F!+@`Y
M80Y`^2'\6-.!,@`Y80Y`^2'\4-.!-@`Y80Y`^2'\2-.!.@`Y80Y`^8$^`#EA
M$D#Y(?Q8TX%"`#EA$D#Y(?Q0TX%&`#EA$D#Y(?Q(TX%*`#EA$D#Y@4X`.>\;
M0/WS4T&I]5M"J?U[Q*CB\O\7`@>`4D(``4L!`(!20GQ`DWWR_Y>M__\7_7N_
MJ?T#`)']>\&HP`-?U@```````````````"5S+R5S````1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E
M>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0````````
M``!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$52
M3#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````
M````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,
M7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U0
M1$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M`````#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D``````!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S
M)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L`````"YP
M87(`````<VAO<G0@<F5A9````````"5S)7-C86-H92TE<R5S```E<R5S=&5M
M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&`````````!P97)L
M`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C0```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``````````+64````````M+0```````%5315(`````
M55-%4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```
M````+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S
M971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@
M<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#
M(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D
M9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D
M<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A
M(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*
M<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D
M8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]
M"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M
M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`[
M"F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@
M/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D
M9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E
M=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE
M(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O
M9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N
M86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%
M<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;
M0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@
M;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U
M=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U
M=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@
M)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH
M(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@
M:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U
M9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I
M<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B
M)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK
M*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D
M=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I
M;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF
M;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D
M(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE0
M7TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C
M=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S
M=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R
M;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A
M<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q
M<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("10
M2UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B
M.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR
M96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E
M;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A
M9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@
M<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@
M("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL
M92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K
M97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];
M7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64[
M"FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I
M;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\
M)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T[
M"F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@
M>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@
M(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT
M*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M
M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L
M(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C
M86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(
M12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#
M*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R
M(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z
M.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%
M>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B
M)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C
M:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@
M)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER
M(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI
M(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F
M:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P
M.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S
M+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@
M)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES
M>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP
M;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!
M4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``
M````````0T%#2$4``````````````2-%9P````")J\WO`````/[<NI@`````
M=E0R$`````#PX=+#`````````````````1L#._0````=````X(G__Q`&``!`
MC/__#`$``'",__\@`0``K(S__S0!```,C?__6`$``$"-__]X`0``(([__]@!
M``#`CO__``(``$"0__]0`@``8)+__Z0"``#(DO__R`(```"3___<`@``,)3_
M_PP#``!`E/__(`,``*"6__^(`P``S);__ZP#``!`F/__"`0``%"=__]$!```
MR)W__V@$``!@GO__A`0``*B?___$!```R)___^0$``#,H/__(`4``,BF__^H
M!0```*G__]P%````JO__0`8``-"Z__]L!@``$+O__XP&``"0O/__R`8`````
M```0``````````%Z4@`$>!X!&PP?`!`````8````+(O__S``````````$```
M`"P```!(B___/``````````@````0````'"+__]@`````$$.()T$G@-"DP)4
MWMW3#@`````<````9````*R+__\T`````$0.$)T"G@%'WMT.`````%P```"$
M````P(O__^``````00Y`G0B>!T63!I0%EP*8`4.6`Y4$5M;51-[=U]C3U`X`
M00Y`DP:4!94$E@.7`I@!G0B>!T[6U4/>W=?8T]0.`$$.0),&E`67`I@!G0B>
M!R0```#D````0(S__YP`````00ZP`42=!)X#0I,"5@K3W=X.`$$+``!,````
M#`$``+B,__]T`0```$$.P`%#G0:>!4:4`Y,$1-332=W>#@!!#L`!DP24`YT&
MG@5!E@&5`G8*U--!UM5!"TG3U-76090#DP1!E@&5`E````!<`0``Z(W__R`"
M````00Y@09T*G@E"DPB4!TV5!I8%EP28`W\*U]C5UM/4W=X.`$$+29H!F0)=
M"MK900M(V=I"F0*:`4+9VD&:`9D"0MK9`"````"P`0``M(___V@`````00X@
MG02>`T63`I0!3=[=T]0.`!````#4`0``^(___RP`````````+````.@!```<
MD/__,`$```!!#B"=!)X#1`[`0),"E`%\"@X@0][=T]0.`$$+````$````!@"
M```<D?__!`````````!D````+`(``!B1__]<`@```$$.4)T*G@E%#N`ADPB4
M!Y4&E@5?"@Y00][=U=;3U`X`00M(EP1"F`-#F0)#F@%D"M=!V$'90=I!"VD*
MUT'80=E!VD$+1-?8V=I!EP1!F`-!F0)!F@$``"````"4`@``$)/__RP`````
M00X@G02>`T.3`D;>W=,.`````%@```"X`@``&)/__W0!````00X@G02>`T,.
ML"!(DP)!E`%H"M-"U$$.($'>W0X`00M!TT'42PX@0=[=#@!!#K`@DP*4`9T$
MG@-,"M-"U$(+0=/409,"090!````.````!0#```PE/__$`4```!!#F!#G0J>
M"4*3")0'1I4&E@67!)@#F0(#+0$*V=?8U=;3U-W>#@!!"P``(````%`#```$
MF?__>`````!!#B!%G0*>`50*W=X.`$$+````&````'0#``!8F?__C`````!!
M#J`"19T:GAD``#P```"0`P``U)G__T@!````00XPG0:>!40.L(`$DP24`Y4"
ME@%"#L"`!'H*#K"`!$$.,$/>W=76T]0.`$$+```<````T`,``-R:__\@````
M`$$.$)T"G@%&WMT.`````#@```#P`P``W)K__P0!````00Y`0YT&G@5"DP24
M`T*5`I8!60K5UM/4W=X.`$$+70K5UM/4W=X.`$$+`(0````L!```I)O___P%
M````00Z0`T6=#)X+1),*E`E#E0B6!T.7!I@%6)H#F00":0K:V4;7V-76T]3=
MW@X`00MHFP)$VTK9VD[7V-76T]3=W@X`00Z0`Y,*E`F5")8'EP:8!9D$F@.;
M`IT,G@L"7`K;00L"0-M!FP)!V=K;09H#F01!FP(````P````M`0``!BA__\T
M`@```$$.4$6=")X'0I,&E`5$E026`T.7`@)8"M?5UM/4W=X.`$$+,````.@$
M```<H___^`````!!#C!#G02>`T*3`I0!6PK3U-W>#@!!"UH*T]3=W@X`00L`
M`"P````<!0``R(/__PP"````00Y@0YT&G@5(DP24`Y4"E@$"5@K5UM/4W=X.
M`$$+`"@```!,!0``N*/__]`0````00X0G0*>`4<.H`4#*00*#A!!WMT.`$$+
M````'````'@%``!<M/__0`````!!#A"=`IX!3M[=#@`````X````F`4``'RT
M__^``0```$$.4)T*G@E#DPB4!T*5!I8%0I<$F`-"F0("3`K>W=G7V-76T]0.
M`$$+```T````U`4``,"U___$`0```$$.0)T(G@=#DP:4!4.5!)8#0@5/`@)A
M"M[=U=;3U`9/#@!!"P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````S"````````!L(`````````$`````````
MZ0(````````!`````````/0"````````'0````````!*!`````````P`````
M````N!D````````-`````````!12````````&0````````"@^P$``````!L`
M````````"``````````:`````````*C[`0``````'``````````(````````
M`/7^_V\`````>`(````````%`````````"@-````````!@````````!H`P``
M``````H`````````:`0````````+`````````!@`````````%0``````````
M``````````,`````````D/T!```````"`````````'`%````````%```````
M```'`````````!<`````````2!0````````'`````````)`1````````"```
M``````"X`@````````D`````````&``````````>``````````@`````````
M^___;P`````!```(`````/G__V\`````$```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-`9````````T!D```````#0&0```````-`9````````T!D```````#0&0``
M`````-`9````````T!D```````#0&0```````-`9````````T!D```````#0
M&0```````-`9````````T!D```````#0&0```````-`9````````T!D`````
M``#0&0```````-`9````````T!D```````#0&0```````-`9````````T!D`
M``````#0&0```````-`9````````T!D```````#0&0```````-`9````````
MT!D```````#0&0```````-`9````````T!D```````#0&0```````-`9````
M````T!D```````#0&0```````-`9````````T!D```````#0&0```````-`9
M````````T!D```````#0&0```````-`9````````T!D```````#0&0``````
M`-`9````````T!D```````#0&0```````-`9````````T!D```````#0&0``
M`````-`9````````T!D```````#0&0```````-`9````````T!D```````#0
M&0```````-`9````````L/L!````````````````````````````````````
M`````````````+@9````````````````````````````````````````````
M`````````````````*`=```````````````````44@``````````````````
M`````````````````````````@``````"E!!4BYP;0H``````````/A5````
M````B%(``````````````````'A3````````V%4```````#@50```````.A5
M````````\%4``````````````````,!5````````R%4`````````````````
M``!6````````1T-#.B`H06QP:6YE(#$T+C,N,"D@,30N,RXP```N<VAS=')T
M86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R
M87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M````````````````````````````````````"P````<````"`````````#@"
M````````.`(````````D````````````````````!```````````````````
M`!X````!`````@````````!<`@```````%P"````````&@``````````````
M``````$````````````````````F````]O__;P(`````````>`(```````!X
M`@```````.P`````````!``````````(````````````````````,`````L`
M```"`````````&@#````````:`,```````#`"0````````4````#````"```
M```````8`````````#@````#`````@`````````H#0```````"@-````````
M:`0```````````````````$```````````````````!`````!`````(`````
M````D!$```````"0$0```````+@"````````!``````````(`````````!@`
M````````2@````0```!"`````````$@4````````2!0```````!P!0``````
M``0````2````"``````````8`````````%0````!````!@````````"X&0``
M`````+@9````````$`````````````````````0```````````````````!/
M`````0````8`````````T!D```````#0&0```````,`#````````````````
M```0````````````````````6@````$````&`````````*`=````````H!T`
M``````!T-```````````````````(````````````````````&`````!````
M!@`````````44@```````!12````````$`````````````````````0`````
M``````````````!F`````0````(`````````,%(````````P4@```````)!!
M```````````````````0````````````````````;@````$````"````````
M`,"3````````P),```````#T````````````````````!```````````````
M`````'P````!`````@````````"XE````````+B4````````#`8`````````
M``````````@```````````````````"&````#@````,`````````H/L!````
M``"@^P````````@````````````````````(``````````@`````````D@``
M``\````#`````````*C[`0``````J/L````````(````````````````````
M"``````````(`````````)X````&`````P````````"P^P$``````+#[````
M````X`$````````%``````````@`````````$`````````"G`````0````,`
M````````D/T!``````"0_0```````'`"```````````````````(````````
M``@`````````K`````$````#`````````````@`````````!``````"`````
M````````````````"````````````````````+(````(`````P````````"`
M``(``````(```0``````6`````````````````````@`````````````````
M``"W`````0```#````````````````````"```$``````!P`````````````
M```````!``````````$``````````0````,`````````````````````````
HG``!``````#``````````````````````0``````````````````````
